@@ -83,7 +83,8 @@ impl Selector {
     /// Check if the `element` matches the `selector`.
     /// 
     /// ```
-    /// use html_editor::{Node, Element, Selector, Htmlifiable};
+    /// use html_editor::{Node, Element, Selector};
+    /// use html_editor::prelude::*;
     /// 
     /// let element: Element = Element::new(
     ///     "div",
@@ -143,7 +144,8 @@ pub trait Queryable {
     /// Query the node in `self` for the given selector.
     ///
     /// ```
-    /// use html_editor::{parse, Element, Selector, Queryable};
+    /// use html_editor::{parse, Element, Selector};
+    /// use html_editor::prelude::*;
     ///
     /// let html = r#"
     ///     <!DOCTYPE html>
@@ -158,13 +160,15 @@ pub trait Queryable {
     ///     </html>"#;
     /// 
     /// let selector: Selector = Selector::from("#app");
-    /// let app: Element = parse(html).query(&selector).unwrap();
+    /// let app: Element = parse(html).unwrap().query(&selector).unwrap();
     /// ```
     fn query(&self, selector: &Selector) -> Option<Element>;
+
     /// Query all the nodes in `self` for the given selector.
     /// 
     /// ```
-    /// use html_editor::{parse, Element, Selector, Queryable};
+    /// use html_editor::{parse, Element, Selector};
+    /// use html_editor::prelude::*;
     ///
     /// let html = r#"
     ///     <!DOCTYPE html>
@@ -181,7 +185,7 @@ pub trait Queryable {
     ///     </html>"#;
     /// 
     /// let selector: Selector = Selector::from(".btn");
-    /// let app: Vec<Element> = parse(html).query_all(&selector);
+    /// let app: Vec<Element> = parse(html).unwrap().query_all(&selector);
     /// ```
     fn query_all(&self, selector: &Selector) -> Vec<Element>;
 }
@@ -190,7 +194,7 @@ impl Queryable for Vec<Node> {
     fn query(&self, selector: &Selector) -> Option<Element> {
         for node in self {
             if node.is_element() {
-                let element = node.clone().try_into_element().unwrap();
+                let element = node.clone().into_element();
 
                 if selector.matches(&element) {
                     return Some(element);
@@ -203,11 +207,12 @@ impl Queryable for Vec<Node> {
         }
         None
     }
+
     fn query_all(&self, selector: &Selector) -> Vec<Element> {
         let mut elements = Vec::new();
         for node in self {
             if node.is_element() {
-                let element = node.clone().try_into_element().unwrap();
+                let element = node.clone().into_element();
                 // Recursively traverse the descendants nodes
                 let sub_elements = element.query_all(selector);
                 elements.extend(sub_elements);
@@ -225,6 +230,7 @@ impl Queryable for Element {
     fn query(&self, selector: &Selector) -> Option<Element> {
         self.children.query(selector)
     }
+    
     fn query_all(&self, selector: &Selector) -> Vec<Element> {
         self.children.query_all(selector)
     }
