@@ -1,4 +1,5 @@
-use html_editor::{parse, Editable, Htmlifiable, Node, Selector};
+use html_editor::{parse, Node, Selector};
+use html_editor::prelude::*;
 
 const HTML: &str = r#"
     <!DOCTYPE html>
@@ -41,13 +42,13 @@ fn insert() {
         Vec::new(),
         vec![Node::Text(r#"console.log("Hello World")"#.to_string())],
     );
-    let html = parse(HTML).insert_to(&body_selector, script).html();
+    let html = parse(HTML).unwrap().insert_to(&body_selector, script).html();
     assert_eq!(html, INSERTED_HTML);
 }
 
 #[test]
 fn remove() {
     let meta_selector = Selector::from("meta");
-    let html = parse(HTML).remove_by(&meta_selector).html();
+    let html = parse(HTML).unwrap().remove_by(&meta_selector).html();
     assert_eq!(html, REMOVED_HTML);
 }
