@@ -1,4 +1,5 @@
-use html_editor::{parse, Htmlifiable, Editable};
+use html_editor::parse;
+use html_editor::prelude::*;
 
 const HTML: &str = r#"
     <div>
@@ -8,13 +9,13 @@ const HTML: &str = r#"
 
 #[test]
 fn original_html() {
-    let html = parse(HTML).html();
+    let html = parse(HTML).unwrap().html();
     assert_eq!(html, HTML);
 }
 
 #[test]
 fn trimmed_html() {
-    let html = parse(HTML).trim().html();
+    let html = parse(HTML).unwrap().trim().html();
     assert_eq!(
         html,
         r#"<div><span id="class">Hello</span><span class="id">World</span></div>"#
