@@ -1,4 +1,5 @@
-use html_editor::{parse, Queryable, Selector};
+use html_editor::prelude::*;
+use html_editor::{parse, Selector};
 
 const HTML: &str = r#"
     <div>
@@ -9,25 +10,24 @@ const HTML: &str = r#"
 
 #[test]
 fn nodes_query() {
-    let nodes = parse(HTML);
+    let nodes = parse(HTML).unwrap();
     let element = nodes.query(&Selector::from("span")).unwrap();
     println!("{:?}", element);
 }
 
 #[test]
 fn nodes_query_all() {
-    let nodes = parse(HTML);
+    let nodes = parse(HTML).unwrap();
     let elements = nodes.query_all(&Selector::from("span"));
     println!("{:?}", elements);
 }
 
 #[test]
 fn element_query() {
-    let nodes = parse(HTML);
+    let nodes = parse(HTML).unwrap();
     let node = nodes.into_iter().nth(1).unwrap();
     let element = node
-        .try_into_element()
-        .unwrap()
+        .into_element()
         .query(&Selector::from("span"))
         .unwrap();
     println!("{:?}", element);
@@ -35,18 +35,17 @@ fn element_query() {
 
 #[test]
 fn element_query_all() {
-    let nodes = parse(HTML);
+    let nodes = parse(HTML).unwrap();
     let node = nodes.into_iter().nth(1).unwrap();
     let elements = node
-        .try_into_element()
-        .unwrap()
+        .into_element()
         .query_all(&Selector::from("span"));
     println!("{:?}", elements);
 }
 
 #[test]
 fn class_query() {
-    let nodes = parse(HTML);
+    let nodes = parse(HTML).unwrap();
     let element = nodes.query(&Selector::from(".last")).unwrap();
     println!("{:?}", element);
 }
